library booking_card_layout;

import 'package:booking_card_layout/tv_theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_phone_direct_caller/flutter_phone_direct_caller.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:intl/intl.dart';

import 'constants.dart';

class TrainCardLayout{
  final String referenceNo;
  final String assessmentCode;
  final String dateOfJourney;
  final String fromCity;
  final String toCity;
  final String statusCompany;
  final String statusTv;
  final String userName;
  final BuildContext context;
  final List<dynamic> people;

  TrainCardLayout({
    required this.context,
    required this.referenceNo,
    required this.assessmentCode,
    required this.dateOfJourney,
    required this.fromCity,
    required this.toCity,
    required this.statusCompany,
    required this.people,
    required this.statusTv,
    required this.userName,
  });

  showEmployeeDetails(BuildContext context){
    showDialog(context: context, builder: (BuildContext buContext){
      return AlertDialog(
        content: SizedBox(
          width: MediaQuery.of(context).size.width,
          height: 300,
          child: Column(
            children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  Expanded(
                      flex: 5,
                      child: Container(
                          alignment: Alignment.center,
                          child: Text("Employee Details",style: GoogleFonts.lato(fontWeight: FontWeight.w700,fontSize: 20),))),
                  Expanded(
                    flex: 1,
                    child: Container(
                      alignment: Alignment.topRight,
                      child: IconButton(
                          onPressed: (){Navigator.pop(context);},
                          icon: const Icon(Icons.cancel_outlined)),
                    ),
                  ),
                ],
              ),
              SizedBox(
                height: 200,
                child: ListView.builder(
                    itemCount: people.length,
                    itemBuilder: (BuildContext context,int index){
                      return ListTile(
                        trailing: IconButton(
                          icon: const Icon(Icons.call,color: Colors.green,),
                          onPressed: ()async{
                            await FlutterPhoneDirectCaller.callNumber(people[index].peopleContact.toString());
                          },
                        ),
                        subtitle: Text("${people[index].peopleContact}"),
                        title: Text(people[index].peopleName!,style: GoogleFonts.lato(textStyle: const TextStyle(fontSize: 16,fontWeight: FontWeight.w600)),),
                      );
                    }
                ),
              )
            ],
          ),
        ),
      );
    });
  }

  Widget normal(){
    return Container(
      padding: const EdgeInsets.all(2),
      child: Card(
        elevation: 5,
        surfaceTintColor: TVTheme.whiteColor,
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Container(
              height: Constants.taxiCardTop,
              color: TVTheme.blackColor,
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Padding(
                    padding: const EdgeInsets.only(left: 10),
                    child: Text(referenceNo.toString(),style: GoogleFonts.lato(fontWeight: FontWeight.w600,color: TVTheme.primaryColor,fontSize: Constants.subHeader),),
                  ),
                ],
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(left: 10),
              child: Text("Assessment Code - ${assessmentCode.toString()}",style: GoogleFonts.lato(fontWeight: FontWeight.w500,color: TVTheme.blackColor,fontSize: Constants.subHeader)),
            ),
            const Divider(height: 2),
            Padding(
              padding: const EdgeInsets.only(left: 5,right: 5,top: 5),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  Expanded(
                    flex: 2,
                    child: Container(
                      child: Column(
                        children: [
                          Text("${DateTime.parse(dateOfJourney).day}",style: GoogleFonts.ubuntu(fontWeight: FontWeight.w700,fontSize: Constants.title),),
                          Text("${DateFormat("MMM").format(DateTime.parse(dateOfJourney))} ${DateTime.parse(dateOfJourney).year}",style: GoogleFonts.lato(fontSize: Constants.header),),
                          Text(DateFormat.jm().format(DateTime.parse(dateOfJourney)),style: GoogleFonts.ubuntu(fontWeight: FontWeight.w500,fontSize: Constants.subHeader),),

                        ],
                      ),
                    ),
                  ),
                  Expanded(
                    flex: 4,
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: [
                        Row(
                          mainAxisAlignment: MainAxisAlignment.start,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Icon(FontAwesomeIcons.locationDot,size: Constants.iconSize,color: TVTheme.secondColor,),
                            Expanded(child: Text(" ${fromCity.toString()} ",overflow: TextOverflow.ellipsis,maxLines: 1,style: GoogleFonts.lato(textStyle: TextStyle(fontWeight: FontWeight.w500,fontSize: Constants.subHeader)),)),
                          ],
                        ),
                        const SizedBox(height: 10,),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          crossAxisAlignment: CrossAxisAlignment.center,
                          children: [
                            Icon(FontAwesomeIcons.locationArrow,size: Constants.iconSize,color: TVTheme.secondColor,),
                            Expanded(
                                child: Text(
                                  toCity.toString() ==""?" Not Available ": " ${toCity.toString()} ",
                                  overflow: TextOverflow.ellipsis,
                                  maxLines: 1,
                                  style: GoogleFonts.lato(fontWeight: FontWeight.w500,fontSize: Constants.subHeader),)),
                          ],
                        ),

                      ],
                    ),
                  ),
                ],
              ),
            ),
            const Divider(height: 2,),
            Row(
              children: [
                Expanded(
                  flex: 3,
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Expanded(
                          flex: 3,
                          child: Container(
                              padding: const EdgeInsets.only(left: 10),
                              alignment:Alignment.topLeft,
                              child: Text(
                                  "Approver",
                                  style: GoogleFonts.lato(fontSize: Constants.subHeader)
                              )
                          )),
                      Expanded(
                          flex: 4,
                          child: Container(
                              alignment:Alignment.topLeft,
                              child: Text(
                                  statusCompany.toString(),
                                  overflow: TextOverflow.ellipsis,
                                  style: GoogleFonts.lato(
                                      textStyle:  TextStyle(
                                          fontWeight: FontWeight.w600,
                                          fontSize: Constants.subHeader
                                      )
                                  )
                              )
                          )
                      ),
                    ],
                  ),
                ),

                Expanded(
                  flex: 3,
                  child:
                  people!.isEmpty?
                  Container(
                      padding: const EdgeInsets.only(left: 10),
                      child: Text(
                        "No Co-passengers",
                        style: GoogleFonts.lato(fontSize: Constants.subHeader),
                      )
                  ):
                  GestureDetector(
                    onTap: (){
                      showEmployeeDetails(context);
                    },
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Expanded(
                            flex: 3,
                            child: Container(
                                padding: const EdgeInsets.only(left: 10),
                                alignment:Alignment.topLeft,
                                child: Text(
                                    "People",
                                    style: GoogleFonts.lato(fontSize: Constants.subHeader)
                                )
                            )
                        ),
                        Expanded(
                            flex: 4,
                            child: Row(
                              children: [
                                Container(
                                    padding: const EdgeInsets.only(right: 5),
                                    alignment:Alignment.topLeft,
                                    child: Text(
                                        people!.length.toString(),
                                        style: GoogleFonts.lato(textStyle:  TextStyle(fontWeight: FontWeight.w600,fontSize: Constants.subHeader))
                                    )
                                ),

                                Icon(Icons.info_outline,size: Constants.iconSize,)
                              ],
                            )
                        ),

                      ],
                    ),
                  ),
                )
              ],
            ),
            Row(
              children: [
                Expanded(
                  flex: 3,
                  child:Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Expanded(
                          flex: 3,
                          child: Container(
                              padding: const EdgeInsets.only(left: 10),
                              alignment:Alignment.topLeft,
                              child: Text(
                                  "Taxivaxi",
                                  style: GoogleFonts.lato(fontSize: Constants.subHeader)
                              )
                          )
                      ),
                      Expanded(
                          flex: 4,
                          child: Container(
                              alignment:Alignment.topLeft,
                              child: Text(
                                  statusTv.toString(),
                                  style: GoogleFonts.lato(
                                      textStyle: TextStyle(
                                          fontWeight: FontWeight.w600,
                                          fontSize: Constants.subHeader
                                      )
                                  )
                              )
                          )
                      ),
                    ],
                  ),
                ),
                Expanded(
                  flex: 3,
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Expanded(
                          flex: 3,
                          child: Container(
                              padding: const EdgeInsets.only(left: 10),
                              alignment:Alignment.topLeft,
                              child: Text(
                                  "SPOC",
                                  style: GoogleFonts.lato(fontSize: Constants.subHeader)
                              )
                          )),
                      Expanded(
                          flex: 4,
                          child: Container(
                              alignment:Alignment.topLeft,
                              child: Text(
                                  userName!.toString(),
                                  overflow: TextOverflow.ellipsis,
                                  style: GoogleFonts.lato(
                                      textStyle:  TextStyle(
                                          fontWeight: FontWeight.w600,
                                          fontSize: Constants.subHeader
                                      )
                                  )
                              )
                          )
                      )

                    ],
                  ),
                ),

              ],
            ),
            const SizedBox(height: 5),


          ],
        ),
      ),
    );
  }
}